#-----------------------------------------------------------------------------
# Compatible: SketchUp 7 (PC)
#             (other versions untested)
#-----------------------------------------------------------------------------
#
# Thomas Thomassen
# thomas[at]thomthom[dot]net
#
#-----------------------------------------------------------------------------

require 'sketchup.rb'
require 'TT_Lib2/core.rb'

TT::Lib.compatible?('2.4.0', 'Inputbox Test')

#-----------------------------------------------------------------------------


module TT::Plugins::InputboxTest
  
  ### CONSTANTS ### --------------------------------------------------------
  
  VERSION = '1.0.0'
  
  
  ### MENU & TOOLBARS ### --------------------------------------------------
  
  unless file_loaded?( File.basename(__FILE__) )
    m = TT.menu('Plugins').add_submenu('TT::GUI')
    m.add_item('TT::GUI::Inputbox')     { self.test_inputbox }
    m.add_item('TT::Plugins::CleanUp')  { self.test_cleanup }
  end 
  
  
  ### MAIN SCRIPT ### ------------------------------------------------------
  
  def self.test_inputbox
    options = {
      :title => 'TT::GUI::Inputbox',
      :pref_key => 'TT::GUI::Inputbox',
      :modal => true,
      :accept_label => 'Save',
      :cancel_label => 'Abort'
    }
    i = TT::GUI::Inputbox.new(options)
    i.add_control( {
      :label => 'Hello',
      :value => 'World',
      :description => 'Lorem ipsum <b>dolor</b> sit amet.',
    } )
    i.add_control( {
      :label => 'Checkbox1',
      :value => true
    } )
    i.add_control( {
      :label => 'Checkbox2',
      :value => false
    } )
    i.add_control( {
      :label => 'Integer',
      :value => 123
    } )
    i.add_control( {
      :label => 'Float',
      :value => 1.23
    } )
    i.add_control( {
      :label => 'Length',
      :value => 1.23.m
    } )
    ms = Sketchup.active_model.materials
    i.add_control( {
      :label => 'Dropdown List1',
      :value => (ms.current) ? ms.current.display_name : nil,
      :options => ms.map { |m| m.display_name },
      :description => 'Unordered ordered.'
    } )
    i.add_control( {
      :label => 'Dropdown List2',
      :value => (ms.current) ? ms.current.display_name : nil,
      :options => ms.map { |m| m.display_name },
      :order => 1,
      :natrual_order => true,
      :description => 'Naturally ordered.'
    } )
    i.add_control( {
      :label => 'List1',
      :value => (ms.current) ? ms.current.display_name : nil,
      :options => ms.map { |m| m.display_name },
      :order => -1,
      :natrual_order => true,
      :description => 'Naturally ordered reversed.',
      :size => 5
    } )
    i.add_control( {
      :label => 'List2',
      :value => ms.to_a[0..1].map { |m| m.display_name },
      :options => ms.map { |m| m.display_name },
      :order => -1,
      :natrual_order => true,
      :description => 'Multiple Selection.',
      :size => 5,
      :multiple => true
    } )
    i.add_control( {
      :label => 'Radioboxes1',
      :value => 'Hello World',
      :options => ['Hello World', 'Lorem Ipsum', 'Foo Bar'],
      :type => TT::GUI::Inputbox::CT_RADIOBOX
    } )
    i.add_control( {
      :label => 'Radioboxes2',
      :value => 'Monkeys',
      :options => ['Cheese', 'Monkeys'],
      :type => TT::GUI::Inputbox::CT_RADIOBOX
    } )
    i.prompt { |results|
      puts 'Results returned:'
      p results
      #puts i.get_html
    }
  end
  
  
    def self.test_cleanup
    options = {
      :title => 'TT::Plugins::CleanUp',
      :pref_key => 'TT::Plugins::CleanUp',
      :modal => true,
      :accept_label => 'CleanUp',
      :cancel_label => 'Cancel',
      :align => 0.3
    }
    i = TT::GUI::Inputbox.new(options)
    i.add_control( {
      :label => 'Scope',
      :value => 'Local',
      :options => ['Selected', 'Local', 'Model'],
      :type => TT::GUI::Inputbox::CT_RADIOBOX,
      :group => 'General'
    } )
    i.add_control( {
      :label => 'Validate Results',
      :value => true,
      :group => 'General'
    } )
    i.add_control( {
      :label => 'Merge Coplanar Faces',
      :value => true,
      :group => 'Coplanar Faces'
    } )
    i.add_control( {
      :label => 'Ignore Normals',
      :value => false,
      :group => 'Coplanar Faces'
    } )
    i.add_control( {
      :label => 'Ignore Materials',
      :value => false,
      :group => 'Coplanar Faces'
    } )
    i.add_control( {
      :label => 'Ignore UV',
      :value => true,
      :group => 'Coplanar Faces'
    } )
    i.add_control( {
      :label => 'Remove Duplicate Faces',
      :value => false,
      :group => 'Faces'
    } )
    i.add_control( {
      :label => 'Repair Split Edges',
      :value => true,
      :group => 'Edges'
    } )
    i.add_control( {
      :label => 'Remove Lonely Edges',
      :value => true,
      :group => 'Edges'
    } )
    i.add_control( {
      :label => 'Remove Edge Materials',
      :value => false,
      :group => 'Edges'
    } )
    i.add_control( {
      :label => 'Smooth Edges by Angle',
      :value => 0.0,
      :group => 'Edges'
    } )
    i.prompt { |results|
      puts 'Results returned:'
      p results
      #puts i.get_html
    }
  end
  
  
  ### DEBUG ### ------------------------------------------------------------
  
  def self.reload
    TT::Lib.reload
    load __FILE__
  end

end # module

#-----------------------------------------------------------------------------

file_loaded( File.basename(__FILE__) )

#-----------------------------------------------------------------------------